@@ -1,6 +1,7 @@
 test_that("plot.OGRFeature / plot.OGRFeatureSet work", {
     f <- system.file("extdata/ynp_fires_1984_2022.gpkg", package = "gdalraster")
     lyr <- new(GDALVector, f, "mtbs_perims")
+    on.exit(lyr$close())
 
     lyr$returnGeomAs <- "WKB"
     feat <- lyr$getNextFeature()
@@ -31,13 +32,12 @@ test_that("plot.OGRFeature / plot.OGRFeatureSet work", {
     expect_identical(plot(feat), feat)
     feat_set <- lyr$fetch(3)
     expect_identical(plot(feat_set), feat_set)
-
-    lyr$close()
 })
 
 test_that("print.OGRFeature / print.OGRFeatureSet work", {
     f <- system.file("extdata/ynp_fires_1984_2022.gpkg", package = "gdalraster")
     lyr <- new(GDALVector, f, "mtbs_perims")
+    on.exit(lyr$close())
 
     lyr$returnGeomAs <- "WKB"
     feat <- lyr$getNextFeature()
@@ -75,17 +75,14 @@ test_that("print.OGRFeature / print.OGRFeatureSet work", {
     feat_set <- lyr$fetch(3)
     expect_identical(print(feat_set), feat_set)
 
-    lyr$close()
-
     # GeoJSON with NULL geometries
     f <- system.file("extdata/test_ogr_geojson_mixed_timezone.geojson",
                      package = "gdalraster")
-    lyr <- new(GDALVector, f, "test")
+    lyr2 <- new(GDALVector, f, "test")
+    on.exit(lyr2$close())
 
     feat <- lyr$getNextFeature()
     expect_identical(print(feat), feat)
     feat_set <- lyr$fetch(-1)
     expect_identical(print(feat_set), feat_set)
-
-    lyr$close()
 })
